@@ -243,7 +243,7 @@ sub plotting {
     while (time < $s) {
         my $x = int(rand($screen_width));
         my $y = int(rand($screen_height));
-        $F->set_color({ 'alpha' => 255, 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'alpha' => 255, 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->plot({ 'x' => $x, 'y' => $y });
     } ## end while (time < $s)
 } ## end sub plotting
@@ -258,7 +258,7 @@ sub lines {
     }
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->line({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'antialiased' => $aa });
     }
 } ## end sub lines
@@ -275,7 +275,7 @@ sub angle_lines {
     my $s     = time + $factor;
     my $angle = 0;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->angle_line({ 'x' => $center_x, 'y' => $center_y, 'radius' => ($center_y - $F->{'Y_CLIP'}), 'angle' => $angle, 'antialiased' => $aa });
         $angle += 1.1;
         $angle -= 360 if ($angle >= 360);
@@ -288,7 +288,7 @@ sub boxes {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)) });
     }
 } ## end sub boxes
@@ -299,7 +299,7 @@ sub filled_boxes {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'filled' => 1 });
     }
 } ## end sub filled_boxes
@@ -345,8 +345,8 @@ sub hatch_filled_boxes {
     print_it($F, 'Hatch Filled Box Test');
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'alpha' => 255, 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
-        $F->set_b_color({ 'alpha' => 255, 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'alpha' => 255, 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
+        $F->set_b_color({ 'alpha' => 255, 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         my $x  = int(rand($XX));
         my $xx = int(rand($XX));
         my $y  = int(rand($YY));
@@ -435,7 +435,7 @@ sub rounded_boxes {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'radius' => 4 + rand($XX / 16) });
     }
 } ## end sub rounded_boxes
@@ -446,7 +446,7 @@ sub filled_rounded_boxes {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'radius' => 4 + rand($XX / 16), 'filled' => 1 });
     }
 } ## end sub filled_rounded_boxes
@@ -457,8 +457,8 @@ sub hatch_filled_rounded_boxes {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
-        $F->set_b_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
+        $F->set_b_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'radius' => 4 + rand($XX / 16), 'filled' => 1, 'hatch' => $HATCHES[int(rand(scalar(@HATCHES)))] });
     }
     $F->attribute_reset();
@@ -471,7 +471,7 @@ sub vertical_gradient_rounded_boxes {
     my $s = time + $factor;
     while (time < $s) {
 
-        #        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        #        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         my $x  = int(rand($XX));
         my $xx = int(rand($XX));
         my $y  = int(rand($YY));
@@ -510,7 +510,7 @@ sub horizontal_gradient_rounded_boxes {
     my $s = time + $factor;
     while (time < $s) {
 
-        #        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        #        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         my $x  = int(rand($XX));
         my $xx = int(rand($XX));
         my $y  = int(rand($YY));
@@ -570,7 +570,7 @@ sub circles {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->circle({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y) });
     }
 } ## end sub circles
@@ -581,7 +581,7 @@ sub filled_circles {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->circle({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'filled' => 1 });
     }
 } ## end sub filled_circles
@@ -592,8 +592,8 @@ sub hatch_filled_circles {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
-        $F->set_b_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
+        $F->set_b_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->circle({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'filled' => 1, 'hatch' => $HATCHES[int(rand(scalar(@HATCHES)))] });
     }
     $F->attribute_reset();
@@ -606,7 +606,7 @@ sub vertical_gradient_circles {
     my $s = time + $factor;
     while (time < $s) {
 
-        #        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        #        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         my $x     = int(rand($XX));
         my $r     = int(rand($center_y) + 10);
         my $w     = $r * 2;
@@ -639,7 +639,7 @@ sub horizontal_gradient_circles {
     my $s = time + $factor;
     while (time < $s) {
 
-        #        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        #        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         my $x     = int(rand($XX));
         my $r     = int(rand($center_y) + 10);
         my $w     = $r * 2;
@@ -691,7 +691,7 @@ sub arcs {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->arc({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360) });
     }
 } ## end sub arcs
@@ -701,7 +701,7 @@ sub poly_arcs {
     print_it($F, 'Poly Arc Test');
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->poly_arc({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360) });
     }
 } ## end sub poly_arcs
@@ -712,7 +712,7 @@ sub filled_pies {
 
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 2 : time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->filled_pie({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360) });
     }
 } ## end sub filled_pies
@@ -723,8 +723,8 @@ sub hatch_filled_pies {
 
     my $s = time + ($factor * 2);
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
-        $F->set_b_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
+        $F->set_b_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->filled_pie({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360), 'hatch' => $HATCHES[int(rand(scalar(@HATCHES)))] });
     }
     $F->attribute_reset();
@@ -769,7 +769,7 @@ sub horizontal_gradient_pies {
     my $s = time + $factor;
     while (time < $s) {
 
-        #        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        #        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         my $x     = int(rand($XX));
         my $r     = int(rand($center_y) + 10);
         my $w     = $r * 2;
@@ -827,7 +827,7 @@ sub ellipses {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->ellipse({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xradius' => rand($center_x), 'yradius' => rand($center_y) });
     }
 } ## end sub ellipses
@@ -838,7 +838,7 @@ sub filled_ellipses {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256), 'alpha' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)), 'alpha' => int(rand(256)) });
         $F->ellipse({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xradius' => rand($center_x), 'yradius' => rand($center_y), 'filled' => 1 });
     }
 } ## end sub filled_ellipses
@@ -849,8 +849,8 @@ sub hatch_filled_ellipses {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
-        $F->set_b_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
+        $F->set_b_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->ellipse({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xradius' => rand($center_x), 'yradius' => rand($center_y), 'filled' => 1, 'hatch' => $HATCHES[int(rand(scalar(@HATCHES)))] });
     }
     $F->attribute_reset();
@@ -950,7 +950,7 @@ sub polygons {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         my $points = int(rand(2)) + 3;
         my $coords = [];
         foreach my $p (1 .. $points) {
@@ -971,7 +971,7 @@ sub filled_polygons {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         my $points = int(rand(2)) + 3;
         my $coords = [];
         foreach my $p (1 .. $points) {
@@ -992,8 +992,8 @@ sub hatch_filled_polygons {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
-        $F->set_b_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
+        $F->set_b_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         my $points = int(rand(2)) + 3;
         my $coords = [];
         foreach my $p (1 .. $points) {
@@ -1101,7 +1101,7 @@ sub beziers {
 
     my $s = time + $factor;
     while (time < $s) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         my @coords = ();
         foreach my $c (1 .. int(rand(20))) {
             push(@coords, int(rand($XX)), int(rand($YY)));
@@ -1186,27 +1186,27 @@ sub flood_fill {
     my $image = $IMAGES[int(rand(scalar(@IMAGES)))];
 
     if ($XX > 255) {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->polygon({ 'coordinates' => [220 * $xm, 190 * $ym, 1520 * $xm, 80 * $xm, 1160 * $xm, $YY, 960 * $xm, 540 * $ym, 760 * $xm, 780 * $ym] });
 
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->polygon({ 'coordinates' => [1270 * $xm, 570 * $ym, 970 * $xm, 170 * $ym, 600 * $xm, 500 * $ym] });
 
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->circle({ 'x' => 500 * $xm, 'y' => 320 * $ym, 'radius' => 100 * $xm });
         sleep 1 if ($F->{'ACCELERATED'});
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
 
         #        $F->plot({x=>350*$xm,y=>250*$ym,pixel_size=>10});sleep 20;
         $F->fill({ 'x' => 350 * $xm, 'y' => 250 * $ym, 'texture' => $image });
 
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->fill({ 'x' => 960 * $xm, 'y' => 440 * $ym });
     } else {
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->polygon({ 'coordinates' => [$center_x, 3, 3, $YY - 3, $center_x, $center_y, $XX - 3, $YY - 4] });
 
-        $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
+        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->fill({ 'x' => 3, 'y' => 3 });
     } ## end else [ if ($XX > 255) ]
     sleep $factor if ($F->{'ACCELERATED'});
@@ -1609,13 +1609,13 @@ sub alpha_drawing {
     $F->blit_write($image2);
     sleep 2;
 
-    $F->set_color({ 'red' => 0, 'green' => 255, 'blue' => 255, 'alpha' => rand(256) });
+    $F->set_color({ 'red' => 0, 'green' => 255, 'blue' => 255, 'alpha' => int(rand(256)) });
     $F->rbox({ 'x' => 0, 'y' => 0, 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
 
-    $F->set_color({ 'red' => 255, 'green' => 0, 'blue' => 255, 'alpha' => rand(256) });
+    $F->set_color({ 'red' => 255, 'green' => 0, 'blue' => 255, 'alpha' => int(rand(256)) });
     $F->rbox({ 'x' => $XX / 4, 'y' => $YY / 4, 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
 
-    $F->set_color({ 'red' => 255, 'green' => 255, 'blue' => 0, 'alpha' => rand(256) });
+    $F->set_color({ 'red' => 255, 'green' => 255, 'blue' => 0, 'alpha' => int(rand(256)) });
     $F->rbox({ 'x' => ($XX / 2), 'y' => ($YY / 2), 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
     sleep $factor;
 } ## end sub alpha_drawing
