@@ -8,75 +8,79 @@ no strict 'subs';
 no warnings;         # We have to be as quiet as possible
 
 use constant {
-    TRUE  => 1,
-      FALSE => 0,
-      NORMAL_MODE => 0,    #   Constants for DRAW_MODE
-      XOR_MODE    => 1,    #   Constants for DRAW_MODE
-      OR_MODE     => 2,    #   Constants for DRAW_MODE
-      AND_MODE    => 3,    #   Constants for DRAW_MODE
-      MASK_MODE   => 4,    #   Constants for DRAW_MODE
-      UNMASK_MODE => 5,    #   Constants for DRAW_MODE
-      ALPHA_MODE  => 6,    #   Constants for DRAW_MODE
+    TRUE        => 1,
+    FALSE       => 0,
+
+    NORMAL_MODE => 0,    #   Constants for DRAW_MODE
+    XOR_MODE    => 1,    #   Constants for DRAW_MODE
+    OR_MODE     => 2,    #   Constants for DRAW_MODE
+    AND_MODE    => 3,    #   Constants for DRAW_MODE
+    MASK_MODE   => 4,    #   Constants for DRAW_MODE
+    UNMASK_MODE => 5,    #   Constants for DRAW_MODE
+    ALPHA_MODE  => 6,    #   Constants for DRAW_MODE
 
     ARC      => 0,       #   Constants for "draw_arc" method
-      PIE      => 1,       #   Constants for "draw_arc" method
-      POLY_ARC => 2,       #   Constants for "draw_arc" method
+    PIE      => 1,       #   Constants for "draw_arc" method
+    POLY_ARC => 2,       #   Constants for "draw_arc" method
 
     RGB => 0,            #   Constants for color mapping
-      RBG => 1,            #   Constants for color mapping
-      BGR => 2,            #   Constants for color mapping
-      BRG => 3,            #   Constants for color mapping
-      GBR => 4,            #   Constants for color mapping
-      GRB => 5,            #   Constants for color mapping
+    RBG => 1,            #   Constants for color mapping
+    BGR => 2,            #   Constants for color mapping
+    BRG => 3,            #   Constants for color mapping
+    GBR => 4,            #   Constants for color mapping
+    GRB => 5,            #   Constants for color mapping
 
     CENTER_NONE => 0,    #   Constants for centering
-      CENTER_X    => 1,    #   Constants for centering
-      CENTER_Y    => 2,    #   Constants for centering
-      CENTER_XY   => 3,    #   Constants for centering
+    CENTER_X    => 1,    #   Constants for centering
+    CENTER_Y    => 2,    #   Constants for centering
+    CENTER_XY   => 3,    #   Constants for centering
 
     ## Set up the Framebuffer driver "constants" defaults
     # Commands
     FBIOGET_VSCREENINFO => 0x4600,    # These come from "fb.h" in the kernel source
-      FBIOPUT_VSCREENINFO => 0x4601,
-      FBIOGET_FSCREENINFO => 0x4602,
-      FBIOGETCMAP         => 0x4604,
-      FBIOPUTCMAP         => 0x4605,
-      FBIOPAN_DISPLAY     => 0x4606,
-      FBIO_CURSOR         => 0x4608,
-       FBIOGET_CON2FBMAP   => 0x460F,
-      FBIOPUT_CON2FBMAP   => 0x4610,
-      FBIOBLANK           => 0x4611,
-      FBIOGET_VBLANK      => 0x4612,
-      FBIOGET_GLYPH       => 0x4615,
-      FBIOGET_HWCINFO     => 0x4616,
-      FBIOPUT_MODEINFO    => 0x4617,
-      FBIOGET_DISPINFO    => 0x4618,
-      FBIO_WAITFORVSYNC   => 0x4620,
-      VT_GETSTATE         => 0x5603,
+    FBIOPUT_VSCREENINFO => 0x4601,
+    FBIOGET_FSCREENINFO => 0x4602,
+    FBIOGETCMAP         => 0x4604,
+    FBIOPUTCMAP         => 0x4605,
+    FBIOPAN_DISPLAY     => 0x4606,
+    FBIO_CURSOR         => 0x4608,
+    FBIOGET_CON2FBMAP   => 0x460F,
+    FBIOPUT_CON2FBMAP   => 0x4610,
+    FBIOBLANK           => 0x4611,
+    FBIOGET_VBLANK      => 0x4612,
+    FBIOGET_GLYPH       => 0x4615,
+    FBIOGET_HWCINFO     => 0x4616,
+    FBIOPUT_MODEINFO    => 0x4617,
+    FBIOGET_DISPINFO    => 0x4618,
+    FBIO_WAITFORVSYNC   => 0x4620,
+    VT_GETSTATE         => 0x5603,
 
     # FLAGS
     FBINFO_HWACCEL_NONE      => 0x0000,    # These come from "fb.h" in the kernel source
-      FBINFO_HWACCEL_COPYAREA  => 0x0100,
-      FBINFO_HWACCEL_FILLRECT  => 0x0200,
-      FBINFO_HWACCEL_IMAGEBLIT => 0x0400,
-      FBINFO_HWACCEL_ROTATE    => 0x0800,
-      FBINFO_HWACCEL_XPAN      => 0x1000,
-      FBINFO_HWACCEL_YPAN      => 0x2000,
-      FBINFO_HWACCEL_YWRAP     => 0x4000,
+    FBINFO_HWACCEL_COPYAREA  => 0x0100,
+    FBINFO_HWACCEL_FILLRECT  => 0x0200,
+    FBINFO_HWACCEL_IMAGEBLIT => 0x0400,
+    FBINFO_HWACCEL_ROTATE    => 0x0800,
+    FBINFO_HWACCEL_XPAN      => 0x1000,
+    FBINFO_HWACCEL_YPAN      => 0x2000,
+    FBINFO_HWACCEL_YWRAP     => 0x4000,
 };
 
 use List::Util qw(min max);
 
 # use Inline (Config => directory => './.Graphics-Framebuffer-Inline');
-use Inline C => <<END_C;
+our $INLINE = FALSE;
+eval {
+    require Inline;
+    Inline->import ( C => <<'END_C');
 
-/* #include <stdlib.h>
+#include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
 #include <fcntl.h>
 #include <linux/fb.h>
 #include <sys/mman.h>
-#include <sys/ioctl.h> */
+#include <sys/ioctl.h>
 #include <math.h>
 
 #define NORMAL_MODE 0
@@ -93,19 +97,30 @@ use Inline C => <<END_C;
 #define GBR         4
 #define GRB         5
 
-/*
-void c_get_screen_info(char fb_file[]) {
+
+unsigned int c_get_screen_info(char *fb_file) {
     int fbfd = 0;
-    struct fb_var_screeninfo vinfo;
+/*    struct fb_var_screeninfo vinfo;*/
     struct fb_fix_screeninfo finfo;
     
     fbfd = open(fb_file,O_RDWR);
     ioctl(fbfd, FBIOGET_FSCREENINFO, &finfo);
-    ioctl(fbfd, FBIOGET_VSCREENINFO, &vinfo);
+/*    ioctl(fbfd, FBIOGET_VSCREENINFO, &vinfo);*/
     close(fbfd);
+    return(finfo.line_length);
 }
-*/
-void c_plot(char *framebuffer, short x, short y, unsigned char draw_mode, unsigned int color, unsigned char bytes_per_pixel, unsigned int bytes_per_line, unsigned short x_clip, unsigned short y_clip, unsigned short xx_clip, unsigned short yy_clip, unsigned short xoffset, unsigned short yoffset, unsigned char alpha) {
+
+void c_plot(
+    char *framebuffer,
+    short x, short y,
+    unsigned char draw_mode,
+    unsigned int color,
+    unsigned char bytes_per_pixel,
+    unsigned int bytes_per_line,
+    unsigned short x_clip, unsigned short y_clip, unsigned short xx_clip, unsigned short yy_clip,
+    unsigned short xoffset, unsigned short yoffset,
+    unsigned char alpha
+) {
     if (x >= x_clip && x <= xx_clip && y >= y_clip && y <= yy_clip) {
         x += xoffset;
         y += yoffset;
@@ -206,7 +221,18 @@ void c_plot(char *framebuffer, short x, short y, unsigned char draw_mode, unsign
     }
 }
 
-void c_line(char *framebuffer, short x1, short y1, short x2, short y2, char draw_mode, unsigned int color, unsigned char bytes_per_pixel, unsigned int bytes_per_line, unsigned short x_clip, unsigned short y_clip, unsigned short xx_clip, unsigned short yy_clip, unsigned short xoffset, unsigned short yoffset, unsigned char alpha) {
+void c_line(
+    char *framebuffer,
+    short x1, short y1, short x2, short y2,
+    unsigned char draw_mode,
+    unsigned int color,
+    unsigned char bytes_per_pixel,
+    unsigned int bytes_per_line,
+    unsigned short x_clip, unsigned short y_clip, unsigned short xx_clip, unsigned short yy_clip,
+    unsigned short xoffset, unsigned short yoffset,
+    unsigned char alpha
+) {
+/*    printf("X=%d, Y=%d, XX=%d, YY=%d, DM=%d, C=%d, BPP=%d, BPL=%d, XC=%d, YC=%d, XXC=%d, YYC=%d, XO=%d, YO=%d, A=%d\\n", x1,y1,x2,y2,draw_mode,color,bytes_per_pixel,bytes_per_line,x_clip,y_clip,xx_clip,yy_clip,xoffset,yoffset,alpha);
 
     int cx, cy,
       ix, iy,
@@ -268,11 +294,12 @@ void c_line(char *framebuffer, short x1, short y1, short x2, short y2, char draw
               cy += iy;
           } while (dy > 0);
     }
+*/    
     
     
-    
-/*    int shortLen = yy - y;
-    int longLen  = xx - x;
+    int shortLen = y2 - y1;
+    int longLen  = x2 - x1;
+    int yLonger  = false;
 
     if (abs(shortLen) > abs(longLen)) {
         int swap = shortLen;
@@ -286,38 +313,38 @@ void c_line(char *framebuffer, short x1, short y1, short x2, short y2, char draw
     } else {
         decInc = (shortLen << 16) / longLen;
     }
-
+    int count;
     if (yLonger) {
         if (longLen > 0) {
-            longLen += y;
-            for (int count = 0x8000 + (x << 16); y <= longLen; ++y) {
-                c_plot(framebuffer, count >> 16, y, draw_mode, color, bytes_per_pixel, bytes_per_line, x_clip, y_clip, xx_clip, yy_clip, xoffset, yoffset, alpha);
+            longLen += y1;
+            for (count = 0x8000 + (x1 << 16); y1 <= longLen; ++y1) {
+                c_plot(framebuffer, count >> 16, y1, draw_mode, color, bytes_per_pixel, bytes_per_line, x_clip, y_clip, xx_clip, yy_clip, xoffset, yoffset, alpha);
                 count += decInc;
             }
             return;
         }
-        longLen += y;
-        for (int count = 0x8000 + (x << 16); y >= longLen; --y) {
-            c_plot(framebuffer, count >> 16, y, draw_mode, color, bytes_per_pixel, bytes_per_line, x_clip, y_clip, xx_clip, yy_clip, xoffset, yoffset, alpha);
+        longLen += y1;
+        for (count = 0x8000 + (x1 << 16); y1 >= longLen; --y1) {
+            c_plot(framebuffer, count >> 16, y1, draw_mode, color, bytes_per_pixel, bytes_per_line, x_clip, y_clip, xx_clip, yy_clip, xoffset, yoffset, alpha);
             count -= decInc;
         }
         return;    
     }
     
     if (longLen > 0) {
-        longLen += x;
-        for (int count = 0x8000 + (y << 16); x <= longLen; ++x) {
-            c_plot(framebuffer, x, count >> 16, draw_mode, color, bytes_per_pixel, bytes_per_line, x_clip, y_clip, xx_clip, yy_clip, xoffset, yoffset, alpha);
+        longLen += x1;
+        for (count = 0x8000 + (y1 << 16); x1 <= longLen; ++x1) {
+            c_plot(framebuffer, x1, count >> 16, draw_mode, color, bytes_per_pixel, bytes_per_line, x_clip, y_clip, xx_clip, yy_clip, xoffset, yoffset, alpha);
             count += decInc;
         }
         return;
     }
-    longLen += x;
-    for (int count = 0x8000 + (y << 16); x >= longLen; --x) {
-        c_plot(framebuffer, x, count >> 16, draw_mode, color, bytes_per_pixel, bytes_per_line, x_clip, y_clip, xx_clip, yy_clip, xoffset, yoffset, alpha);
+    longLen += x1;
+    for (count = 0x8000 + (y1 << 16); x1 >= longLen; --x1) {
+        c_plot(framebuffer, x1, count >> 16, draw_mode, color, bytes_per_pixel, bytes_per_line, x_clip, y_clip, xx_clip, yy_clip, xoffset, yoffset, alpha);
         count -= decInc;
     }
-*/
+
 }
 
 void c_blit_write(char *framebuffer, unsigned short screen_width, unsigned short screen_height, unsigned int bytes_per_line, unsigned short xoffset, unsigned short yoffset, char *blit_data, short x, short y, unsigned short w, unsigned short h, unsigned char bytes_per_pixel, unsigned char draw_mode, unsigned char alpha, unsigned int bcolor, unsigned short x_clip, unsigned short y_clip, unsigned short xx_clip, unsigned short yy_clip) {
@@ -694,10 +721,13 @@ void c_monochrome(char *pixels, unsigned int size, unsigned short color_order, u
 
 
 END_C
+      $INLINE = TRUE;
+};
 
 BEGIN {
     our $VERSION = 1.00;
-    our @EXPORT_OK = qw(c_monochrome c_convert_16_24 c_convert_24_16);
+    our @EXPORT_OK = qw(c_monochrome c_convert_16_24 c_convert_24_16 c_get_screen_info c_plot c_line c_blit_write c_flip_vertical c_flip_horizontal c_rotate );
+    our @EXPORT    = qw( $INLINE );
 }
 
 sub _convert_16_to_24 {
@@ -1656,16 +1686,16 @@ sub plot {
             $size = abs($size);
             $self->circle({ 'x' => $x, 'y' => $y, 'radius' => ($size / 2), 'filled' => 1, 'pixel_size' => 1 });
         } else {
-            $self->rbox({ 'x' => $x, 'y' => $y, 'width' => $size, 'height' => $size, 'filled' => TRUE, 'pixel_size' => 1 });
+            $self->rbox({ 'x' => $x - ($width / 2), 'y' => $y - ($height / 2), 'width' => $size, 'height' => $size, 'filled' => TRUE, 'pixel_size' => 1 });
         }
     } else {
         $self->wait_for_console() if ($self->{'WAIT_FOR_CONSOLE'});
-        if (0 && $self->{'ACCELERATED'} && ! $self->{'FILE_MODE'}) {
+        if ($self->{'ACCELERATED'} && ! $self->{'FILE_MODE'}) {
             c_plot(
                 $self->{'SCREEN'},
                 $x, $y,
                 $self->{'DRAW_MODE'},
-                unpack('I',$self->{'COLOR'}),
+                $self->{'INT_COLOR'},
                 $self->{'BYTES'},
                 $self->{'BYTES_PER_LINE'},
                 $self->{'X_CLIP'},
@@ -1783,164 +1813,261 @@ sub drawto {
     my $antialiased = $params->{'antialiased'} || 0;
     my $XX          = $x_end;
     my $YY          = $y_end;
-    # Determines if the coordinates sent were right-side-up or up-side-down.
-    if ($start_x > $x_end) {
-        $width = $start_x - $x_end;
-    } else {
-        $width = $x_end - $start_x;
-    }
-    if ($start_y > $y_end) {
-        $height = $start_y - $y_end;
-    } else {
-        $height = $y_end - $start_y;
-    }
 
-    if (0 && $self->{'ACCELERATED'} && ! $self->{'FILE_MODE'}) {
+    if ($self->{'ACCELERATED'} && ! $self->{'FILE_MODE'} && ! $antialiased) {
         c_line(
             $self->{'SCREEN'},
-            $start_x,
-            $start_y,
-            $x_end,
-            $y_end,
+            $start_x, $start_y, $x_end, $y_end,
             $self->{'DRAW_MODE'},
-            unpack('I',$self->{'COLOR'}),
+            $self->{'INT_COLOR'},
             $self->{'BYTES'},
             $self->{'BYTES_PER_LINE'},
-            $self->{'X_CLIP'},
-            $self->{'Y_CLIP'},
-            $self->{'XX_CLIP'},
-            $self->{'YY_CLIP'},
-            $self->{'XOFFSET'},
-            $self->{'YOFFSET'},
+            $self->{'X_CLIP'}, $self->{'Y_CLIP'}, $self->{'XX_CLIP'}, $self->{'YY_CLIP'},
+            $self->{'XOFFSET'}, $self->{'YOFFSET'},
             $self->{'COLOR_ALPHA'}
         );
     } else {
     
-
-    # We need only plot if start and end are the same
-    if (($x_end == $start_x) && ($y_end == $start_y)) {
-        $self->plot({ 'x' => $x_end, 'y' => $y_end, 'pixel_size' => $size });
-
-        # Else, let's get to drawing
-    } elsif ($x_end == $start_x) {    # Draw a perfectly verticle line
-        if ($start_y > $y_end) {      # Draw direction is UP
-            foreach my $y ($y_end .. $start_y) {
-                $self->plot({ 'x' => $start_x, 'y' => $y, 'pixel_size' => $size });
-            }
-        } else {                      # Draw direction is DOWN
-            foreach my $y ($start_y .. $y_end) {
-                $self->plot({ 'x' => $start_x, 'y' => $y, 'pixel_size' => $size });
-            }
-        }
-    } elsif ($y_end == $start_y) {    # Draw a perfectly horizontal line (fast)
-        $x_end   = max($self->{'X_CLIP'}, min($x_end,   $self->{'XX_CLIP'}));
-        $start_x = max($self->{'X_CLIP'}, min($start_x, $self->{'XX_CLIP'}));
-        $width   = abs($x_end - $start_x);
-        if ($size == 1) {
-            if ($start_x > $x_end) {
-                $self->blit_write({ 'x' => $x_end, 'y' => $y_end, 'width' => $width, 'height' => 1, 'image' => $self->{'COLOR'} x $width });    # Blitting a horizontal line is much faster!
-            } else {
-                $self->blit_write({ 'x' => $start_x, 'y' => $start_y, 'width' => $width, 'height' => 1, 'image' => $self->{'COLOR'} x $width });    # Blitting a horizontal line is much faster!
-            }
+        # Determines if the coordinates sent were right-side-up or up-side-down.
+        if ($start_x > $x_end) {
+            $width = $start_x - $x_end;
         } else {
-            if ($start_x > $x_end) {
-                $self->blit_write({ 'x' => $x_end, 'y' => ($y_end - ($size / 2)), 'width' => $width, 'height' => $size, 'image' => $self->{'COLOR'} x ($width * $size) });    # Blitting a horizontal line is much faster!
-            } else {
-                $self->blit_write({ 'x' => $start_x, 'y' => ($y_end - ($size / 2)), 'width' => $width, 'height' => $size, 'image' => $self->{'COLOR'} x ($width * $size) });    # Blitting a horizontal line is much faster!
-            }
-        } ## end else [ if ($size == 1) ]
-    } elsif ($antialiased) {
-        $self->_draw_line_antialiased($start_x, $start_y, $x_end, $y_end);
-    } elsif ($width > $height) {    # Wider than it is high
-        my $factor = $height / $width;
-        if (($start_x < $x_end) && ($start_y < $y_end)) {    # Draw UP and to the RIGHT
-            while ($start_x < $x_end) {
-                $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
-                $start_y += $factor;
-                $start_x++;
-            }
-        } elsif (($start_x > $x_end) && ($start_y < $y_end)) {    # Draw UP and to the LEFT
-            while ($start_x > $x_end) {
-                $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
-                $start_y += $factor;
-                $start_x--;
-            }
-        } elsif (($start_x < $x_end) && ($start_y > $y_end)) {    # Draw DOWN and to the RIGHT
-            while ($start_x < $x_end) {
-                $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
-                $start_y -= $factor;
-                $start_x++;
-            }
-        } elsif (($start_x > $x_end) && ($start_y > $y_end)) {    # Draw DOWN and to the LEFT
-            while ($start_x > $x_end) {
-                $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
-                $start_y -= $factor;
-                $start_x--;
-            }
-        } ## end elsif (($start_x > $x_end...))
-    } elsif ($width < $height) {    # Higher than it is wide
-        my $factor = $width / $height;
-        if (($start_x < $x_end) && ($start_y < $y_end)) {    # Draw UP and to the RIGHT
-            while ($start_y < $y_end) {
-                $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
-                $start_x += $factor;
-                $start_y++;
-            }
-        } elsif (($start_x > $x_end) && ($start_y < $y_end)) {    # Draw UP and to the LEFT
-            while ($start_y < $y_end) {
-                $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
-                $start_x -= $factor;
-                $start_y++;
-            }
-        } elsif (($start_x < $x_end) && ($start_y > $y_end)) {    # Draw DOWN and to the RIGHT
-            while ($start_y > $y_end) {
-                $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
-                $start_x += $factor;
-                $start_y--;
-            }
-        } elsif (($start_x > $x_end) && ($start_y > $y_end)) {    # Draw DOWN and to the LEFT
-            while ($start_y > $y_end) {
-                $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
-                $start_x -= $factor;
-                $start_y--;
-            }
-        } ## end elsif (($start_x > $x_end...))
-    } else {    # $width == $height
-        if (($start_x < $x_end) && ($start_y < $y_end)) {    # Draw UP and to the RIGHT
-            while ($start_y < $y_end) {
-                $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
-                $start_x++;
-                $start_y++;
-            }
-        } elsif (($start_x > $x_end) && ($start_y < $y_end)) {    # Draw UP and to the LEFT
-            while ($start_y < $y_end) {
-                $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
-                $start_x--;
-                $start_y++;
-            }
-        } elsif (($start_x < $x_end) && ($start_y > $y_end)) {    # Draw DOWN and to the RIGHT
-            while ($start_y > $y_end) {
-                $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
-                $start_x++;
-                $start_y--;
-            }
-        } elsif (($start_x > $x_end) && ($start_y > $y_end)) {    # Draw DOWN and to the LEFT
-            while ($start_y > $y_end) {
-                $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
-                $start_x--;
-                $start_y--;
-            }
-        } ## end elsif (($start_x > $x_end...))
+            $width = $x_end - $start_x;
+        }
+        if ($start_y > $y_end) {
+            $height = $start_y - $y_end;
+        } else {
+            $height = $y_end - $start_y;
+        }
 
-    } ## end else [ if (($x_end == $start_x...))]
+        # We need only plot if start and end are the same
+        if (($x_end == $start_x) && ($y_end == $start_y)) {
+            $self->plot({ 'x' => $x_end, 'y' => $y_end, 'pixel_size' => $size });
+            
+            # Else, let's get to drawing
+        } elsif ($x_end == $start_x) {    # Draw a perfectly verticle line
+            if ($start_y > $y_end) {      # Draw direction is UP
+                foreach my $y ($y_end .. $start_y) {
+                    $self->plot({ 'x' => $start_x, 'y' => $y, 'pixel_size' => $size });
+                }
+            } else {                      # Draw direction is DOWN
+                foreach my $y ($start_y .. $y_end) {
+                    $self->plot({ 'x' => $start_x, 'y' => $y, 'pixel_size' => $size });
+                }
+            }
+        } elsif ($y_end == $start_y) {    # Draw a perfectly horizontal line (fast)
+            $x_end   = max($self->{'X_CLIP'}, min($x_end,   $self->{'XX_CLIP'}));
+            $start_x = max($self->{'X_CLIP'}, min($start_x, $self->{'XX_CLIP'}));
+            $width   = abs($x_end - $start_x);
+            if ($size == 1) {
+                if ($start_x > $x_end) {
+                    $self->blit_write({ 'x' => $x_end, 'y' => $y_end, 'width' => $width, 'height' => 1, 'image' => $self->{'COLOR'} x $width });    # Blitting a horizontal line is much faster!
+                } else {
+                    $self->blit_write({ 'x' => $start_x, 'y' => $start_y, 'width' => $width, 'height' => 1, 'image' => $self->{'COLOR'} x $width });    # Blitting a horizontal line is much faster!
+                }
+            } else {
+                if ($start_x > $x_end) {
+                    $self->blit_write({ 'x' => $x_end, 'y' => ($y_end - ($size / 2)), 'width' => $width, 'height' => $size, 'image' => $self->{'COLOR'} x ($width * $size) });    # Blitting a horizontal line is much faster!
+                } else {
+                    $self->blit_write({ 'x' => $start_x, 'y' => ($y_end - ($size / 2)), 'width' => $width, 'height' => $size, 'image' => $self->{'COLOR'} x ($width * $size) });    # Blitting a horizontal line is much faster!
+                }
+            } ## end else [ if ($size == 1) ]
+        } elsif ($antialiased) {
+            $self->_draw_line_antialiased($start_x, $start_y, $x_end, $y_end);
+        } elsif ($width > $height) {    # Wider than it is high
+            my $factor = $height / $width;
+            if (($start_x < $x_end) && ($start_y < $y_end)) {    # Draw UP and to the RIGHT
+                while ($start_x < $x_end) {
+                    $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
+                    $start_y += $factor;
+                    $start_x++;
+                }
+            } elsif (($start_x > $x_end) && ($start_y < $y_end)) {    # Draw UP and to the LEFT
+                while ($start_x > $x_end) {
+                    $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
+                    $start_y += $factor;
+                    $start_x--;
+                }
+            } elsif (($start_x < $x_end) && ($start_y > $y_end)) {    # Draw DOWN and to the RIGHT
+                while ($start_x < $x_end) {
+                    $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
+                    $start_y -= $factor;
+                    $start_x++;
+                }
+            } elsif (($start_x > $x_end) && ($start_y > $y_end)) {    # Draw DOWN and to the LEFT
+                while ($start_x > $x_end) {
+                    $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
+                    $start_y -= $factor;
+                    $start_x--;
+                }
+            } ## end elsif (($start_x > $x_end...))
+        } elsif ($width < $height) {    # Higher than it is wide
+            my $factor = $width / $height;
+            if (($start_x < $x_end) && ($start_y < $y_end)) {    # Draw UP and to the RIGHT
+                while ($start_y < $y_end) {
+                    $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
+                    $start_x += $factor;
+                    $start_y++;
+                }
+            } elsif (($start_x > $x_end) && ($start_y < $y_end)) {    # Draw UP and to the LEFT
+                while ($start_y < $y_end) {
+                    $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
+                    $start_x -= $factor;
+                    $start_y++;
+                }
+            } elsif (($start_x < $x_end) && ($start_y > $y_end)) {    # Draw DOWN and to the RIGHT
+                while ($start_y > $y_end) {
+                    $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
+                    $start_x += $factor;
+                    $start_y--;
+                }
+            } elsif (($start_x > $x_end) && ($start_y > $y_end)) {    # Draw DOWN and to the LEFT
+                while ($start_y > $y_end) {
+                    $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
+                    $start_x -= $factor;
+                    $start_y--;
+                }
+            } ## end elsif (($start_x > $x_end...))
+        } else {    # $width == $height
+            if (($start_x < $x_end) && ($start_y < $y_end)) {    # Draw UP and to the RIGHT
+                while ($start_y < $y_end) {
+                    $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
+                    $start_x++;
+                    $start_y++;
+                }
+            } elsif (($start_x > $x_end) && ($start_y < $y_end)) {    # Draw UP and to the LEFT
+                while ($start_y < $y_end) {
+                    $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
+                    $start_x--;
+                    $start_y++;
+                }
+            } elsif (($start_x < $x_end) && ($start_y > $y_end)) {    # Draw DOWN and to the RIGHT
+                while ($start_y > $y_end) {
+                    $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
+                    $start_x++;
+                    $start_y--;
+                }
+            } elsif (($start_x > $x_end) && ($start_y > $y_end)) {    # Draw DOWN and to the LEFT
+                while ($start_y > $y_end) {
+                    $self->plot({ 'x' => $start_x, 'y' => $start_y, 'pixel_size' => $size });
+                    $start_x--;
+                    $start_y--;
+                }
+            } ## end elsif (($start_x > $x_end...))
+            
+        } ## end else [ if (($x_end == $start_x...))]
     }
     $self->{'X'} = $XX;
     $self->{'Y'} = $YY;
-
+    
     select($self->{'FB'});
     $| = 1;
 } ## end sub drawto
 
+sub _adj_plot {
+    my ($self, $x, $y, $c, $s) = @_;
+    $self->set_color({ 'red' => $s->{'red'} * $c, 'green' => $s->{'green'} * $c, 'blue' => $s->{'blue'} * $c });
+    $self->plot({ 'x' => $x, 'y' => $y });
+}
+
+sub _draw_line_antialiased {
+    my ($self, $x0, $y0, $x1, $y1) = @_;
+
+    my $saved = { %{ $self->{'SET_COLOR'} } };
+
+    my $plot = \&_adj_plot;
+
+    if (abs($y1 - $y0) > abs($x1 - $x0)) {
+        $plot = sub { _adj_plot(@_[0, 2, 1, 3, 4]) };
+        ($x0, $y0, $x1, $y1) = ($y0, $x0, $y1, $x1);
+    }
+
+    if ($x0 > $x1) {
+        ($x0, $x1, $y0, $y1) = ($x1, $x0, $y1, $y0);
+    }
+
+    my $dx       = $x1 - $x0;
+    my $dy       = $y1 - $y0;
+    my $gradient = $dy / $dx;
+
+    my @xends;
+    my $intery;
+
+    # handle the endpoints
+    for my $xy ([$x0, $y0], [$x1, $y1]) {
+        my ($x, $y) = @{$xy};
+        my $xend = _round($x);
+        my $yend = $y + $gradient * ($xend - $x);
+        my $xgap = _rfpart($x + 0.5);
+
+        my $x_pixel = $xend;
+        my $y_pixel = int($yend);
+        push @xends, $x_pixel;
+
+        $plot->($self, $x_pixel, $y_pixel,     _rfpart($yend) * $xgap, $saved);
+        $plot->($self, $x_pixel, $y_pixel + 1, _fpart($yend) * $xgap,  $saved);
+        next if defined $intery;
+
+        # first y-intersection for the main loop
+        $intery = $yend + $gradient;
+    } ## end for my $xy ([$x0, $y0],...)
+
+    # main loop
+
+    for my $x ($xends[0] + 1 .. $xends[1] - 1) {
+        $plot->($self, $x, int($intery),     _rfpart($intery), $saved);
+        $plot->($self, $x, int($intery) + 1, _fpart($intery),  $saved);
+        $intery += $gradient;
+    }
+    $self->set_color($saved);
+} ## end sub _draw_line_antialiased
+sub _round {
+    return (int(0.5 + shift));
+}
+
+sub _fpart {
+    my $x = shift;
+    return ($x - int $x);
+}
+
+sub _rfpart {
+    return (1 - _fpart(shift));
+}
+
+sub _transformed_bounds {
+    my $bbox   = shift;
+    my $matrix = shift;
+
+    my $bounds;
+    foreach my $point ([$bbox->start_offset, $bbox->ascent], [$bbox->start_offset, $bbox->descent], [$bbox->end_offset, $bbox->ascent], [$bbox->end_offset, $bbox->descent]) {
+        $bounds = _add_bound($bounds, _transform_point(@{$point}, $matrix));
+    }
+    return (@{$bounds});
+} ## end sub _transformed_bounds
+
+sub _add_bound {
+    my $bounds = shift;
+    my $x      = shift;
+    my $y      = shift;
+
+    $bounds or return ([$x, $y, $x, $y]);
+
+    $x < $bounds->[0] and $bounds->[0] = $x;
+    $y < $bounds->[1] and $bounds->[1] = $y;
+    $x > $bounds->[2] and $bounds->[2] = $x;
+    $y > $bounds->[3] and $bounds->[3] = $y;
+
+    return ($bounds);
+} ## end sub _add_bound
+
+sub _transform_point {
+    my $x      = shift;
+    my $y      = shift;
+    my $matrix = shift;
+
+    return ($x * $matrix->[0] + $y * $matrix->[1] + $matrix->[2], $x * $matrix->[3] + $y * $matrix->[4] + $matrix->[5]);
+} ## end sub _transform_point
+
 1;
 
 =head1 NAME
